@@ -199,15 +199,18 @@ class Rigol_DG4000:
     def phase(self,ch,p):
         self.dev.write(':SOURCe{}:PHASe {}'.format(ch,p));
         
-    def gaussian(self,t,mu,FWHM,a): #Gaussian Function. Inputs: (FWHM, Amplitude, Center)
+    @staticmethod    
+    def gaussian(t,mu,FWHM,a): #Gaussian Function. Inputs: (FWHM, Amplitude, Center)
         sigma = (FWHM)/(2*np.sqrt(2*np.log(2)))
         amplitude = np.sqrt(2*np.pi*sigma**2)*a
         return amplitude*( 1/(sigma * np.sqrt(2*np.pi) ) )*np.exp( -((t-mu)**2 / (2*sigma**2)) )
     
-    def square(self,t,leadingedge,width,amp): #square pulse with duty cycle
+    @staticmethod
+    def square(t,leadingedge,width,amp): #square pulse with duty cycle
         return np.piecewise(t,[(t<=leadingedge),((t>leadingedge) & (t<leadingedge+width)),(t>=leadingedge+width)],[0,amp,0])
     
-    def normalize(self,waveform):
+    @staticmethod
+    def normalize(waveform):
         """
         Description: Normalizes data for arbitrary waveform design, points are limited (Tested 04/03/2022)
         to -1 to 1 Volt
@@ -231,7 +234,7 @@ class Rigol_DG4000:
         Output: None : class method
         """
         buffer_size = 2**14
-        if inspect.ismethod(waveform) == True:
+        if inspect.ismethod(waveform) == True or inspect.isfunction(waveform) == True:
             t = np.linspace(0,signal_width,buffer_size)
             data = np.around(waveform(t,*arg),4)
             datastring = ",".join(map(str,self.normalize(data)))
@@ -290,7 +293,7 @@ class Rigol_DG4000:
                arg* : arguments of the function : misc
         Output: None : class method
         """
-        if inspect.ismethod(func) == True:
+        if inspect.ismethod(waveform) == True or inspect.isfunction(waveform) == True:
             t = np.linspace(0,signal_width,1000)
             data = func(t,*arg)
             datastring = ",".join(map(str, self.normalize(data)))
@@ -818,7 +821,7 @@ class tektronix_AFG3000:
     def freq(self,f):
         self.dev.write('SOURce:FREQuency:FIXed {}'.format(self.__Hz(f)));
 
-    def __Hz(f): 
+    def __Hz(self, f): 
         """
         Description: Sets all frequencies to MHz Unit
 
@@ -851,23 +854,26 @@ class tektronix_AFG3000:
         self.dev.write('SOURCe:VOLTage:UNIT VPP')
 
     def offset(self,offset):  # V_DC
-        self.dev.write('SOURC:VOLTage:OFFSet {}'.format(offset));
+        self.dev.write('SOURce:VOLTage:LEVel:IMMediate:OFFSet {}'.format(offset));
 
     def phase(self,phase):
         self.dev.write('SOURC:PHASe {}'.format(phase));
         
     def burst_delay(self,tdelay):
         self.dev.write('SOUR:BURS:TDEL {}ns'.format(tdelay))
-        
-    def gaussian(self,t,mu,FWHM,a): #Gaussian Function. Inputs: (FWHM, Amplitude, Center)
+    
+    @staticmethod
+    def gaussian(t,mu,FWHM,a): #Gaussian Function. Inputs: (Center, FWHM, Amplitude)
         sigma = (FWHM)/(2*np.sqrt(2*np.log(2)))
         amplitude = np.sqrt(2*np.pi*sigma**2)*a
         return amplitude*( 1/(sigma * np.sqrt(2*np.pi) ) )*np.exp( -((t-mu)**2 / (2*sigma**2)) )
     
-    def square(self,t,leadingedge,width,amp): #square pulse with duty cycle
+    @staticmethod
+    def square(t,leadingedge,width,amp): #square pulse with duty cycle
         return np.piecewise(t,[(t<=leadingedge),((t>leadingedge) & (t<leadingedge+width)),(t>=leadingedge+width)],[0,amp,0])
     
-    def normalize(self, waveform):
+    @staticmethod
+    def normalize(waveform):
         """
         Description: Normalizes data for arbitrary waveform design, points are limited
         to -1 to 1 Volt
@@ -891,15 +897,9 @@ class tektronix_AFG3000:
         """
         buffer_size = 2**14-2
         
-        if waveform[0] != waveform[-1]:
-            waveform[0] = 0
-            waveform[-1] = waveform[0]
-        else:
-            pass
-        
-        if inspect.ismethod(waveform) == True:
+        if inspect.ismethod(waveform) == True or inspect.isfunction(waveform) == True:
 
-            t = np.linspace(0,total_time,buffer_size)
+            t = np.linspace(0,signal_width,buffer_size)
             data = waveform(t,*arg)
 
             datastring = self.normalize(data)
@@ -916,34 +916,37 @@ class tektronix_AFG3000:
             b = -m * datastring.min()
             dac_values = (m * datastring + b)
             np.around(dac_values, out=dac_values)
-            dac_values = dac_values.astype(np.uint16)    
+            dac_values = dac_values.astype(np.uint16)
+            
+        if data[0] != data[-1]:
+            data[0] = 0
+            data[-1] = data[0]
+        else:
+            pass
             
-        factor = max([np.abs(max(data)),np.abs(min(data))])
         self.dev.write('DATA:DEFine EMEMory,{}'.format(len(data)))
         self.dev.write_binary_values("DATA:DATA EMEM1,", dac_values, datatype="H", is_big_endian=True)
         self.dev.write("SOURce:FUNC:SHAPE EMEM1")
-        self.dev.write("SOURce1:VOLTage:LEVel:IMMediate:LOW {}".format(-factor))
-        self.dev.write("SOURce1:VOLTage:LEVel:IMMediate:HIGH {}".format(factor))
+        self.dev.write("SOURce1:VOLTage:LEVel:IMMediate:LOW {}".format(min(data)))
+        self.dev.write("SOURce1:VOLTage:LEVel:IMMediate:HIGH {}".format(max(data)))
         self.dev.write("SOURCE:FREQ {}".format(self.__Hz(1/signal_width)))
 
     def ext_trig(self):
         self.dev.write("TRIGger:SEQuence:SOURce EXTernal")
     
-    def burst(self, ch, mode, cycles):
+    def burst(self, mode, cycles):
         """
         Description: Allows on to use burst functionallity
 
-        Input: ch : channel : int
-               mode : burst mode : int = {'TRIG' = 0, 'GAT' = 1,'INF' = 2}
+        Input: mode : burst mode : int = {'TRIG' = 0, 'GAT' = 1}
                cycles : cycles : int
 
         Output: 
         """
-        modes = ['TRIGgered','GATed','INFinity']
-        self.dev.write('SOURce{}:BURSt:MODE {}'.format(ch,modes[mode]))
-        self.dev.write('SOURce{}:BURSt:TRIGger:SOURce EXT'.format(ch))
-        self.dev.write('SOURce{}:BURSt:NCYCles {}'.format(ch,cycles))
-        self.dev.write('SOURce{}:BURSt ON'.format(ch))
+        modes = ['TRIG','GAT']
+        self.dev.write("SOURCE:BURSt:MODE {}".format(modes[mode]))
+        self.dev.write("SOURCE:BURSt:NCYC {}".format(cycles))
+        self.dev.write("SOURCE:BURSt:STAT ON")
     
     def DC(self, offset):
         """
